@@ -101,7 +101,7 @@ def create_app(
         try:
             result = await executor.run(action_call)
         except ActionExecutionRejection as e:
-            logger.error(e)
+            logger.debug(e)
             body = {"error": e.message, "action_name": e.action_name}
             return response.json(body, status=400)
         except ActionNotFoundException as e:
@@ -137,7 +137,9 @@ def run(
         action_package_name, cors_origins=cors_origins, auto_reload=auto_reload
     )
     ssl_context = create_ssl_context(ssl_certificate, ssl_keyfile, ssl_password)
+    protocol = "https" if ssl_context else "http"
 
+    logger.info(f"Action endpoint is up and running on {protocol}://localhost:{port}")
     app.run("0.0.0.0", port, ssl=ssl_context, workers=utils.number_of_sanic_workers())
 
 
